#!/bin/sh
# 
# simple wrapper script for run_tcp_tests.sh
# specify what hosts you want to test here, and what test settings
#

DATE=`date "+%Y-%m-%d-%H-%M"`
RESULTS_DIR=/storage/data1/tcp-test-results/$DATE
mkdir -p $RESULTS_DIR

#source host and its OS
SRC=lbl-diskpt1.es.net
OS=CentOS7

# list of test hosts
# for more details, look up the host at:  http://stats.es.net/ServicesDirectory/
# e.g: http://stats.es.net/ServicesDirectory/#search=sdm00.rcc.uchicago.edu
#
# amst-pt1.es.net (10G, jumbo, RTT=142)
# eqx-ash-pt1.es.net (1G, jumbo. RTT=63)
# lcgps01.gridpp.rl.ac.uk (1G, mtu=1500, RTT=137)
# psmsu02.aglt2.org (10G, mtu=1500, RTT=62)
# perfext11.ncbi.nlm.nih.gov (10G, mtu=1500, rtt=63)
# perfsonar.ucar.edu (10G, jumbo, rtt=28ms) 
# sdm00.rcc.uchicago.edu (40G host on 10G path, jumbo, rtt = 46)
# ps62.psc.edu (1G, mtu=1500, rtt = 68)

#short host list for testing
#HOSTS="amst-pt1.es.net eqx-ash-pt1.es.net lcgps01.gridpp.rl.ac.uk"
#full list
HOSTS=(amst-pt1.es.net eqx-ash-pt1.es.net lcgps01.gridpp.rl.ac.uk psmsu02.aglt2.org  perfext11.ncbi.nlm.nih.gov perfsonar.ucar.edu sdm00.rcc.uchicago.edu ps62.psc.edu)
# corresponding TCP window size for each of the path
# Note: default perfSONAR autotuning is set to 32M, and some of these paths are long enough to need something bigger.
CWIN=(256M 32M 64M 64M 64M 64M 64M 64M)

# run the following tests

# Test 1: Default Config, single stream
# Test 2: Default Config, parallel streams (default for GridFTP is 4, so suggest 4 for DTN testing)
# Test 3: with FQ, single stream (if supported)
# Test 4: with FQ, parallel streams
# Test 5: with FQ pacing
# Test 6: with FQ pacing and parallel stream


i=0
for h in ${HOSTS[@]}; do

     cwin=${CWIN[$i]}
     ((++i)) 
     echo "testing to host $h with a CWIN of $cwin"

     # arguments to run_tcp_tests.sh 
     # source host, dest host, CWIN, FQ, pacing rate, number of streams

     # sample set of tests for hosts that support FQ
     # test 1: defaults
    ./run_tcp_tests.sh $SRC $h $cwin 0 0 1 $RESULTS_DIR $OS

     # test 2: 4 streams
     OPTS="P4"
     ./run_tcp_tests.sh $SRC $h $cwin 0 0 4 $RESULTS_DIR $OS:$OPTS

     # test 3: with FQ
    ./run_tcp_tests.sh $SRC $h $cwin 1 0 1 $RESULTS_DIR $OS:FQ

     # test 4: with FQ and parallel streams
    ./run_tcp_tests.sh $SRC $h $cwin 1 0 4 $RESULTS_DIR $OS:FQ.P4

     # test 5: with FQ and pacing
    ./run_tcp_tests.sh $SRC $h $cwin 1 7gbit 1 $RESULTS_DIR $OS:FQ:7g

     # test 6: with FQ and pacing and parallel stream
    ./run_tcp_tests.sh $SRC $h $cwin 1 3gbit 4 $RESULTS_DIR $OS:FQ:P4:3g

done


