#!/bin/sh
#
# This is a quick hack of a script to do a iperf3 test via bwctl with various TCP settings, and optionally 
#  do a tcpdump of headers during the test
#
#  Brian Tierney, ESnet (bltierney@es.net)
#
#set -x

# this script expects all the following arguments

HOST1=$1
HOST2=$2
CWIN=$3
FQ=$4
RATE=$5  # (0 = unlimited)
NS=$6
RESULTS_DIR=$7
LABEL=$8

MYPATH="/local/scripts/tcp-test-scripts"

# can also set these...
#set TCP congestion control alg
CC=htcp

# set this to enable tcpdump captures
DO_PCAP=1
#location of dumper.sh script 
PCAPTURE=$MYPATH/dumper.sh
#packet capture interface
ETH=eth10
OUTFILE=$RESULTS_DIR/$HOST1-to-$HOST2:$LABEL

# first make sure GridFTP servers are not running if this is a DTN host
/etc/init.d/globus-gridftp-server stop
/etc/init.d/globus-gridftp-server-writer stop

#set TCP congestion control to requested setting
sysctl -w net.ipv4.tcp_congestion_control=$CC
#clear out any existing TC rules 
/sbin/tc qdisc del dev $ETH root 


#----------------------------------------
if [ $FQ != 0 ] ; then
   if [ $RATE != 0 ] ; then
      /sbin/tc qdisc add dev $ETH root fq maxrate $RATE
   else
      /sbin/tc qdisc add dev $ETH root fq 
   fi
fi

if [ $DO_PCAP == 1 ] ; then
   $PCAPTURE $OUTFILE $HOST2 $ETH start
fi
bwctl -4 -P$NS -s $HOST1 -c $HOST2 -T iperf3 -t60 -w$CWIN --parsable > $OUTFILE.json
if [ $DO_PCAP == 1 ] ; then
   $PCAPTURE $OUTFILE $HOST $ETH stop
fi

# strip out some extra junk from the output JSON file that bwctl adds
grep -v SENDER $DATA_DIR/$OUTFILE.json > tmpfile
mv -f tmpfile $DATA_DIR/$OUTFILE.json

# convert to format that will work with GNUplot
rm -f $NAME.dat
python $MYPATH/iperf3_to_gnuplot.py -f $OUTFILE.json -o $OUTFILE.dat 


#----------------------------------------
#restart GridFTP servers
/etc/init.d/globus-gridftp-server start
/etc/init.d/globus-gridftp-server-writer start

exit

